% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Well_Information.R
\name{well_information}
\alias{well_information}
\title{example well information Data}
\format{
A data frame with the following columns:
    \describe{
      \item{...1}{n/a}
      \item{Protein...2}{Protein in Well 1}
      \item{Ligand...3}{Ligand in Well 1}
      \item{Protein...4}{Protein in Well 2}
      \item{Ligand...5}{Ligand in Well 2}
      \item{Protein...6}{Protein in Well 3}
      \item{Ligand...7}{Ligand in Well 3}
      \item{Protein...8}{Protein in Well 4}
      \item{Ligand...9}{Ligand in Well 4}
      \item{Protein...10}{Protein in Well 5}
      \item{Ligand...11}{Ligand in Well 5}
      \item{Protein...12}{Protein in Well 6}
      \item{Ligand...13}{Ligand in Well 6}
      \item{Protein...14}{Protein in Well 7}
      \item{Ligand...15}{Ligand in Well 7}
      \item{Protein...16}{Protein in Well 8}
      \item{Ligand...17}{Ligand in Well 8}
      \item{Protein...18}{Protein in Well 9}
      \item{Ligand...19}{Ligand in Well 9}
      \item{Protein...20}{Protein in Well 10}
      \item{Ligand...21}{Ligand in Well 10}
      \item{Protein...22}{Protein in Well 11}
      \item{Ligand...23}{Ligand in Well 11}
      \item{Protein...24}{Protein in Well 12}
      \item{Ligand...25}{Ligand in Well 12}
    }
}
\usage{
data(well_information)
}
\value{
well information data frame
}
\description{
Dataset Description:
    This file is a readin using well_information_template. File contains the
    conditions of well, specifying protein and ligand content in well.
    All experimental setup and relevant information are determined and
    manually put in by the author of this package.
}
\keyword{dataset}
